@@ -4,9 +4,11 @@ from typing import List
 def strip_whitespace(string: str) -> str:
     return string.replace(' ', '')
 
+
 def simplify_expression(expr: str) -> str:
     return strip_whitespace(expr).lower()
 
+
 def concatenate_horizontally(*args: str) -> str:
     string_list: List[List[str]] = []
     for string in args:
@@ -20,4 +22,8 @@ def concatenate_horizontally(*args: str) -> str:
             except IndexError:
                 pass
         result += '\n'
-    return result
\ No newline at end of file
+    return result
+
+
+def pad(left_pad: int, body: str, right_pad: int, pad_char: str = ' '):
+    return pad_char * left_pad + body + pad_char * right_pad
